/* $Id: crires_model_io.c,v 1.22 2011-02-07 19:10:34 bristowp Exp $
 *
 * This file is part of the CRIRES Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: bristowp $
 * $Date: 2011-02-07 19:10:34 $
 * $Revision: 1.22 $
 * $Name: not supported by cvs2svn $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*-----------------------------------------------------------------------------
                                Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

#include "crires_model_io.h"
#include "crires_dfs.h"
#include "crires_load.h"

/*----------------------------------------------------------------------------*/
/**
 * @defgroup crires_model_io    IO functions for the model
 */
/*----------------------------------------------------------------------------*/

/**@{*/

/*----------------------------------------------------------------------------*/
/**
  @brief    Load the config model table and fill the struct 
  @param    filename    Config FITS file name
  @param    p_crires    crires structure
  @return   0 if ok, -1 otherwise
 */
/*----------------------------------------------------------------------------*/
int crires_model_io_load_config_best(
        const char      *   config,
        struct crires   *   p_crires)
{
    cpl_table   *   tab ;
    int             nlines ;
    char        *   name ;
    int             i, kk ;
    
    /* Check entries */
    if (config == NULL) return -1 ;
    if (p_crires == NULL) return -1 ;

    /* Load the table */
    if ((tab = crires_load_table_check(config, 1, CRIRES_PROTYPE_MOD_CONF, 
                    -1, -1, 0)) == NULL) {
        cpl_msg_error(__func__, "Cannot load the config table") ;
        return -1 ;
    }
    nlines = cpl_table_get_nrow(tab) ;
    /* Loop on lines */
    for (i=0 ; i<nlines ; i++) {
        name = (char*) cpl_table_get_string(tab, CRIRES_COL_MODEL_CONF_NAME, i);
	/*printf("param %s : %g\n", name, cpl_table_get_double(tab,
	  CRIRES_COL_MODEL_CONF_BEST, i, NULL)) ;*/
        if (!strcmp("temper", name)) p_crires->temper = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_x", name)) p_crires->es_x = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_xf", name)) p_crires->es_xf = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_x_off", name)) p_crires->es_x_off=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_y", name)) p_crires->es_y = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("mues", name)) p_crires->mues = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nues", name)) p_crires->nues = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("taues", name)) p_crires->taues = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_s", name)) p_crires->es_s = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("es_w", name)) p_crires->es_w = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("fcp", name)) p_crires->fcp = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("mup1", name)) p_crires->mup1 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_mup", name)) p_crires->axis_mup = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("penc_co1", name)) p_crires->penc_co1 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("penc_co2", name)) p_crires->penc_co2 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("penc_co3", name)) p_crires->penc_co3 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nup1", name)) p_crires->nup1 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("taup1", name)) p_crires->taup1 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_nup", name)) p_crires->axis_nup = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_taup", name)) p_crires->axis_taup = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("mup2", name)) p_crires->mup2 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nup2", name)) p_crires->nup2 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("taup2", name)) p_crires->taup2 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("rind_delta", name)) 
            p_crires->rind_delta = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("muis", name)) p_crires->muis = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nuis", name)) p_crires->nuis = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("tauis", name)) p_crires->tauis = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("flipisx", name)) p_crires->flipisx = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("flipisy", name)) p_crires->flipisy = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("fis", name)) p_crires->fis = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slitx", name)) p_crires->slitx = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slity", name)) p_crires->slity = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slitrot", name)) p_crires->slitrot = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slitw", name)) p_crires->slitw = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slith", name)) p_crires->slith = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit_on", name)) p_crires->slit_on = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("mug", name)) p_crires->mug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_mug", name)) p_crires->axis_mug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("genc_co1", name)) p_crires->genc_co1 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("genc_co2", name)) p_crires->genc_co2 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("genc_co3", name)) p_crires->genc_co3 = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nug", name)) p_crires->nug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("taug", name)) p_crires->taug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_nug", name)) p_crires->axis_nug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("axis_taug", name)) p_crires->axis_taug = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("sg", name)) p_crires->sg = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("cam_dis", name)) p_crires->cam_dis = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("fk", name)) p_crires->fk = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("mud", name)) p_crires->mud = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("nud", name)) p_crires->nud = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("taud", name)) p_crires->taud = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pix", name)) p_crires->pix = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipx[0]", name)) p_crires->chipx[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipy[0]", name)) p_crires->chipy[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chiprot[0]", name)) 
            p_crires->chiprot[0] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipx[1]", name)) p_crires->chipx[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipy[1]", name)) p_crires->chipy[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chiprot[1]", name)) 
            p_crires->chiprot[1] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipx[2]", name)) p_crires->chipx[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipy[2]", name)) p_crires->chipy[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chiprot[2]", name)) 
            p_crires->chiprot[2] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipx[3]", name)) p_crires->chipx[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chipy[3]", name)) p_crires->chipy[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("chiprot[3]", name)) 
            p_crires->chiprot[3] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xx[0]", name)) p_crires->pc_x_xx[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_x1[0]", name)) p_crires->pc_x_x1[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_yy[0]", name)) p_crires->pc_x_yy[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_y1[0]", name)) p_crires->pc_x_y1[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xy[0]", name)) p_crires->pc_x_xy[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xx[0]", name)) p_crires->pc_y_xx[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_x1[0]", name)) p_crires->pc_y_x1[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_yy[0]", name)) p_crires->pc_y_yy[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_y1[0]", name)) p_crires->pc_y_y1[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xy[0]", name)) p_crires->pc_y_xy[0]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xx[1]", name)) p_crires->pc_x_xx[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_x1[1]", name)) p_crires->pc_x_x1[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_yy[1]", name)) p_crires->pc_x_yy[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_y1[1]", name)) p_crires->pc_x_y1[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xy[1]", name)) p_crires->pc_x_xy[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xx[1]", name)) p_crires->pc_y_xx[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_x1[1]", name)) p_crires->pc_y_x1[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_yy[1]", name)) p_crires->pc_y_yy[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_y1[1]", name)) p_crires->pc_y_y1[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xy[1]", name)) p_crires->pc_y_xy[1]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xx[2]", name)) p_crires->pc_x_xx[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_x1[2]", name)) p_crires->pc_x_x1[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_yy[2]", name)) p_crires->pc_x_yy[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_y1[2]", name)) p_crires->pc_x_y1[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xy[2]", name)) p_crires->pc_x_xy[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xx[2]", name)) p_crires->pc_y_xx[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_x1[2]", name)) p_crires->pc_y_x1[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_yy[2]", name)) p_crires->pc_y_yy[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_y1[2]", name)) p_crires->pc_y_y1[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xy[2]", name)) p_crires->pc_y_xy[2]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xx[3]", name)) p_crires->pc_x_xx[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_x1[3]", name)) p_crires->pc_x_x1[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_yy[3]", name)) p_crires->pc_x_yy[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_y1[3]", name)) p_crires->pc_x_y1[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_x_xy[3]", name)) p_crires->pc_x_xy[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xx[3]", name)) p_crires->pc_y_xx[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_x1[3]", name)) p_crires->pc_y_x1[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_yy[3]", name)) p_crires->pc_y_yy[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_y1[3]", name)) p_crires->pc_y_y1[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("pc_y_xy[3]", name)) p_crires->pc_y_xy[3]=
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("det_array_x", name))
            p_crires->det_array_x = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("det_array_y", name))
            p_crires->det_array_y = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("offx", name)) p_crires->offx = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("offy", name)) p_crires->offy = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("flipx", name)) p_crires->flipx = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("flipy", name)) p_crires->flipy = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[1]", name)) p_crires->slit[1] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[2]", name)) p_crires->slit[2] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[3]", name)) p_crires->slit[3] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[4]", name)) p_crires->slit[4] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[5]", name)) p_crires->slit[5] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[6]", name)) p_crires->slit[6] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
        else if (!strcmp("slit[7]", name)) p_crires->slit[7] = 
            cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST, i, NULL) ;
    }
    /* Conversion from DEG to RAD */
    p_crires->mues *= DEG2RAD ;
    p_crires->nues *= DEG2RAD ;
    p_crires->taues *= DEG2RAD ;
    p_crires->mup1 *= DEG2RAD ;
    p_crires->axis_mup *= DEG2RAD ;
    p_crires->penc_co1 *= DEG2RAD ;
    p_crires->penc_co2 *= DEG2RAD ;
    p_crires->penc_co3 *= DEG2RAD ;
    p_crires->nup1 *= DEG2RAD ;
    p_crires->taup1 *= DEG2RAD ;
    p_crires->axis_nup *= DEG2RAD ;
    p_crires->axis_taup *= DEG2RAD ;
    p_crires->mup2 *= DEG2RAD ;
    p_crires->nup2 *= DEG2RAD ;
    p_crires->taup2 *= DEG2RAD ;
    p_crires->muis *= DEG2RAD ;
    p_crires->nuis *= DEG2RAD ;
    p_crires->tauis *= DEG2RAD ;
    p_crires->slitrot *= DEG2RAD ;
    p_crires->axis_mug *= DEG2RAD ;
    p_crires->axis_nug *= DEG2RAD ;
    p_crires->axis_taug *= DEG2RAD ;
    p_crires->mug *= DEG2RAD ;
    p_crires->genc_co1 *= DEG2RAD ;
    p_crires->genc_co2 *= DEG2RAD ;
    p_crires->genc_co3 *= DEG2RAD ;
    p_crires->nug *= DEG2RAD ;
    p_crires->taug *= DEG2RAD ;
    p_crires->muk *= DEG2RAD ;
    p_crires->nuk *= DEG2RAD ;
    p_crires->tauk *= DEG2RAD ;
    p_crires->mud *= DEG2RAD ;
    p_crires->nud *= DEG2RAD ;
    p_crires->taud *= DEG2RAD ;
    p_crires->chiprot[0] *= DEG2RAD ;
    p_crires->chiprot[1] *= DEG2RAD ;
    p_crires->chiprot[2] *= DEG2RAD ;
    p_crires->chiprot[3] *= DEG2RAD ;
    for (kk=1;kk<60;kk++) {
        p_crires->prism[kk] *= DEG2RAD ;
        p_crires->grat[kk] *= DEG2RAD ;
    }
    cpl_table_delete(tab) ;
    return 0 ;
}

int crires_model_readfits(double * abest,double * amin,
                          double * amax, int * aname,
                          const char * cri_config_file,
                          struct crires *p_crires,
                          ann_all_par *p_all_par)
{
  int ii,jj,kk,compa, par_found, indlen;
  char tempstr[10];
  double d2r;

  cpl_table *   tab ;
  int           nlines ;

    /* Load the table */
    if ((tab = crires_load_table_check(cri_config_file, 1,
                    CRIRES_PROTYPE_MOD_CONF, -1, -1, 0)) == NULL) {
        cpl_msg_error(__func__, "Cannot load the config table") ;
        return -1 ;
    }
    nlines = cpl_table_get_nrow(tab) ;

  for (ii=0 ; ii<nlines ; ii++) {
      (p_all_par+ii)->best=cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_BEST,
              ii, NULL) ;
      (p_all_par+ii)->min = cpl_table_get_double(tab, CRIRES_COL_MODEL_CONF_LOW,
              ii, NULL) ;
      (p_all_par+ii)->max = cpl_table_get_double(tab,CRIRES_COL_MODEL_CONF_HIGH,
              ii, NULL) ;
      (p_all_par+ii)->flag = cpl_table_get_int(tab, CRIRES_COL_MODEL_CONF_FLAG,
              ii, NULL) ;
      sprintf((p_all_par+ii)->name, "%s", (char*)cpl_table_get_string(tab,
                  CRIRES_COL_MODEL_CONF_NAME, ii));
    if ((p_all_par+ii)->flag==1) {
      if ((p_all_par+ii)->best<(p_all_par+ii)->min ||
          (p_all_par+ii)->best>(p_all_par+ii)->max) {
        cpl_msg_error(__func__, "limits wrong in config file for parameter: %s \n",
               (p_all_par+ii)->name);
        return -1;
      }
    }
  }

  jj=0;
  for (ii=0 ; ii<nlines ; ii++) {
    d2r=1.0;
    par_found=0;
/*below the number of char in the variable name MUST be given to strncmp*/
    compa=strncmp((p_all_par+ii)->name,"temper",6);
    if (compa==0) {
      p_crires->temper=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"es_x",4);
    if (compa==0) {
      compa=strncmp((p_all_par+ii)->name,"es_xf",5);
      if (compa!=0) {
	compa=strncmp((p_all_par+ii)->name,"es_x_off",8);
	if (compa!=0) {
	  p_crires->es_x=(p_all_par+ii)->best;
	  par_found=1;
	}
      }
    }
    compa=strncmp((p_all_par+ii)->name,"es_xf",5);
    if (compa==0) {
      p_crires->es_xf=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"es_x_off",8);
    if (compa==0) {
      p_crires->es_x_off=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"es_y",4);
    if (compa==0) {
      p_crires->es_y=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"mues",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->mues=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nues",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nues=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"taues",5);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->taues=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"es_s",4);
    if (compa==0) {
      p_crires->es_s=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"es_w",4);
    if (compa==0) {
      p_crires->es_w=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"fcp",3);
    if (compa==0) {
      p_crires->fcp=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"mup1",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->mup1=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_mup",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_mup=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"penc_co1",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->penc_co1=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"penc_co2",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->penc_co2=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"penc_co3",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->penc_co3=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nup1",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nup1=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"taup1",5);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->taup1=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_nup",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_nup=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_taup",9);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_taup=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"mup2",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->mup2=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nup2",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nup2=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"taup2",5);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->taup2=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"rind_delta",10);
    if (compa==0) {
      p_crires->rind_delta=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"muis",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->muis=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nuis",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nuis=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"tauis",5);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->tauis=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"flipisx",7);
    if (compa==0) {
      p_crires->flipisx=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"flipisy",7);
    if (compa==0) {
      p_crires->flipisy=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"fis",3);
    if (compa==0) {
      p_crires->fis=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slitx",5);
    if (compa==0) {
      p_crires->slitx=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slity",5);
    if (compa==0) {
      p_crires->slity=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slitrot",7);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->slitrot=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slitw",5);
    if (compa==0) {
      p_crires->slitw=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slith",5);
    if (compa==0) {
      p_crires->slith=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slit_on",7);
    if (compa==0) {
      p_crires->slit_on=(int)((p_all_par+ii)->best);
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_mug",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_mug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_nug",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_nug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"axis_taug",9);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->axis_taug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"mug",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->mug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"genc_co1",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->genc_co1=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"genc_co2",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->genc_co2=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"genc_co3",8);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->genc_co3=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nug",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"taug",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->taug=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"sg",2);
    if (compa==0) {
      p_crires->sg=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"cam_dis",7);
    if (compa==0) {
      p_crires->cam_dis=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"muk",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->muk=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nuk",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nuk=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"tauk",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->tauk=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"fk",2);
    if (compa==0) {
      p_crires->fk=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"mud",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->mud=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nud",3);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->nud=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"taud",4);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->taud=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pix",3);
    if (compa==0) {
      p_crires->pix=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipx[0]",8);
    if (compa==0) {
      p_crires->chipx[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipy[0]",8);
    if (compa==0) {
      p_crires->chipy[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chiprot[0]",10);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->chiprot[0]=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipx[1]",8);
    if (compa==0) {
      p_crires->chipx[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipy[1]",8);
    if (compa==0) {
      p_crires->chipy[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chiprot[1]",10);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->chiprot[1]=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipx[2]",8);
    if (compa==0) {
      p_crires->chipx[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipy[2]",8);
    if (compa==0) {
      p_crires->chipy[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chiprot[2]",10);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->chiprot[2]=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipx[3]",8);
    if (compa==0) {
      p_crires->chipx[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chipy[3]",8);
    if (compa==0) {
      p_crires->chipy[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"chiprot[3]",10);
    if (compa==0) {
      d2r=DEG2RAD;
      p_crires->chiprot[3]=(p_all_par+ii)->best*d2r;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xx[0]",10);
    if (compa==0) {
      p_crires->pc_x_xx[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_x1[0]",10);
    if (compa==0) {
      p_crires->pc_x_x1[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_yy[0]",10);
    if (compa==0) {
      p_crires->pc_x_yy[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_y1[0]",10);
    if (compa==0) {
      p_crires->pc_x_y1[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xy[0]",10);
    if (compa==0) {
      p_crires->pc_x_xy[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xx[0]",10);
    if (compa==0) {
      p_crires->pc_y_xx[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_x1[0]",10);
    if (compa==0) {
      p_crires->pc_y_x1[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_yy[0]",10);
    if (compa==0) {
      p_crires->pc_y_yy[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_y1[0]",10);
    if (compa==0) {
      p_crires->pc_y_y1[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xy[0]",10);
    if (compa==0) {
      p_crires->pc_y_xy[0]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xx[1]",10);
    if (compa==0) {
      p_crires->pc_x_xx[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_x1[1]",10);
    if (compa==0) {
      p_crires->pc_x_x1[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_yy[1]",10);
    if (compa==0) {
      p_crires->pc_x_yy[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_y1[1]",10);
    if (compa==0) {
      p_crires->pc_x_y1[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xy[1]",10);
    if (compa==0) {
      p_crires->pc_x_xy[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xx[1]",10);
    if (compa==0) {
      p_crires->pc_y_xx[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_x1[1]",10);
    if (compa==0) {
      p_crires->pc_y_x1[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_yy[1]",10);
    if (compa==0) {
      p_crires->pc_y_yy[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_y1[1]",10);
    if (compa==0) {
      p_crires->pc_y_y1[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xy[1]",10);
    if (compa==0) {
      p_crires->pc_y_xy[1]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xx[2]",10);
    if (compa==0) {
      p_crires->pc_x_xx[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_x1[2]",10);
    if (compa==0) {
      p_crires->pc_x_x1[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_yy[2]",10);
    if (compa==0) {
      p_crires->pc_x_yy[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_y1[2]",10);
    if (compa==0) {
      p_crires->pc_x_y1[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xy[2]",10);
    if (compa==0) {
      p_crires->pc_x_xy[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xx[2]",10);
    if (compa==0) {
      p_crires->pc_y_xx[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_x1[2]",10);
    if (compa==0) {
      p_crires->pc_y_x1[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_yy[2]",10);
    if (compa==0) {
      p_crires->pc_y_yy[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_y1[2]",10);
    if (compa==0) {
      p_crires->pc_y_y1[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xy[2]",10);
    if (compa==0) {
      p_crires->pc_y_xy[2]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xx[3]",10);
    if (compa==0) {
      p_crires->pc_x_xx[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_x1[3]",10);
    if (compa==0) {
      p_crires->pc_x_x1[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_yy[3]",10);
    if (compa==0) {
      p_crires->pc_x_yy[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_y1[3]",10);
    if (compa==0) {
      p_crires->pc_x_y1[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_x_xy[3]",10);
    if (compa==0) {
      p_crires->pc_x_xy[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xx[3]",10);
    if (compa==0) {
      p_crires->pc_y_xx[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_x1[3]",10);
    if (compa==0) {
      p_crires->pc_y_x1[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_yy[3]",10);
    if (compa==0) {
      p_crires->pc_y_yy[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_y1[3]",10);
    if (compa==0) {
      p_crires->pc_y_y1[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"pc_y_xy[3]",10);
    if (compa==0) {
      p_crires->pc_y_xy[3]=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"det_array_x",11);
    if (compa==0) {
      p_crires->det_array_x=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"det_array_y",11);
    if (compa==0) {
      p_crires->det_array_y=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"offx",4);
    if (compa==0) {
      p_crires->offx=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"offy",4);
    if (compa==0) {
      p_crires->offy=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"flipx",5);
    if (compa==0) {
      p_crires->flipx=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"flipy",5);
    if (compa==0) {
      p_crires->flipy=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"simpl",5);
    if (compa==0) {
      p_crires->simpl=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"nx",2);
    if (compa==0) {
      p_crires->nx=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"ny",2);
    if (compa==0) {
      p_crires->ny=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"uvab",4);
    if (compa==0) {
      p_crires->uvab=(p_all_par+ii)->best;
      par_found=1;
    }
    compa=strncmp((p_all_par+ii)->name,"slitp",5);
    if (compa==0) {
      p_crires->slitp=(p_all_par+ii)->best;
      par_found=1;
    }
    for (kk=1;kk<60;kk++) {
      sprintf(tempstr,"prism[%d]",kk);
      indlen=strlen(tempstr);
      compa=strncmp((p_all_par+ii)->name,tempstr,indlen);
      if (compa==0) {
        d2r=DEG2RAD;
        p_crires->prism[kk]=(p_all_par+ii)->best*d2r;
        par_found=2;
      }
    }
    for (kk=1;kk<60;kk++) {
      sprintf(tempstr,"grat[%d]",kk);
      indlen=strlen(tempstr);
      compa=strncmp((p_all_par+ii)->name,tempstr,indlen);
      if (compa==0) {
        d2r=DEG2RAD;
        p_crires->grat[kk]=(p_all_par+ii)->best*d2r;
        par_found=3;
      }
    }
    for (kk=1;kk<60;kk++) {
      sprintf(tempstr,"ord[%d]",kk);
      indlen=strlen(tempstr);
      compa=strncmp((p_all_par+ii)->name,tempstr,indlen);
      if (compa==0) {
        p_crires->ord[kk]=(p_all_par+ii)->best;
        par_found=1;
      }
    }
    for (kk=1;kk<10;kk++) {
      sprintf(tempstr,"slit[%d]",kk);
      indlen=strlen(tempstr);
      compa=strncmp((p_all_par+ii)->name,tempstr,indlen);
      if (compa==0) {
        p_crires->slit[kk]=(p_all_par+ii)->best;
        par_found=1;
      }
    }

    if (par_found==1) {
      if ((p_all_par+ii)->flag!=0) {
        abest[jj]=(p_all_par+ii)->best;
        amin[jj]=(p_all_par+ii)->min-0.0;
        amax[jj]=(p_all_par+ii)->max+0.0;
        aname[jj]=ii;
        //printf("%d %s %d \n", ii, (p_all_par+ii)->name, jj);
        jj++;
      }
    }
    else if (par_found==2) {
      if ((p_all_par+ii)->flag!=0) {
	abest[jj]=(p_all_par+ii)->best;
	amin[jj]=(p_all_par+ii)->min-0.1;
	amax[jj]=(p_all_par+ii)->max+0.1;
	aname[jj]=ii;
	//printf("%d %s %d \n", ii, (p_all_par+ii)->name, jj);
	jj++;
      }
    }
    else if (par_found==3) {
      if ((p_all_par+ii)->flag!=0) {
	abest[jj]=(p_all_par+ii)->best;
	amin[jj]=(p_all_par+ii)->min-0.1;
	amax[jj]=(p_all_par+ii)->max+0.1;
	aname[jj]=ii;
	//printf("%d %s %d \n", ii, (p_all_par+ii)->name, jj);
	jj++;
      }
    }
  }
  cpl_table_delete(tab) ;
  return jj;
}

#define crires_model_config_enter(name, val, index)                            \
    cpl_table_set_string(tab, CRIRES_COL_MODEL_CONF_NAME, index, name) ;       \
    cpl_table_set_double(tab, CRIRES_COL_MODEL_CONF_BEST, index, val) ;        \
    cpl_table_set_double(tab, CRIRES_COL_MODEL_CONF_LOW,  index, val) ;        \
    cpl_table_set_double(tab, CRIRES_COL_MODEL_CONF_HIGH, index, val) ;        \
    cpl_table_set_int(tab, CRIRES_COL_MODEL_CONF_FLAG, index, 0) ;            

cpl_table * crires_model_io_output_cfg(struct crires *p_crires)
{
    cpl_table   *   tab ;
    char            tempstr[10];
    int             nb_parameters ;
    int             i, j ;
  
    /* Initialise */
    if (p_crires->ord[59]!=-999) {
      nb_parameters = 300 ;
    }
    else {
      nb_parameters = 120 ;
    }
    /* Create the table */
    tab = cpl_table_new(nb_parameters) ;
    cpl_table_new_column(tab, CRIRES_COL_MODEL_CONF_BEST, CPL_TYPE_DOUBLE) ;
    cpl_table_new_column(tab, CRIRES_COL_MODEL_CONF_LOW, CPL_TYPE_DOUBLE) ;
    cpl_table_new_column(tab, CRIRES_COL_MODEL_CONF_HIGH, CPL_TYPE_DOUBLE) ;
    cpl_table_new_column(tab, CRIRES_COL_MODEL_CONF_FLAG, CPL_TYPE_INT) ;
    cpl_table_new_column(tab, CRIRES_COL_MODEL_CONF_NAME, CPL_TYPE_STRING) ;

    i = 0 ;
    crires_model_config_enter("temper",     p_crires->temper,       i) ; i++ ;
    crires_model_config_enter("es_x",      p_crires->es_x,        i) ; i++ ;
    crires_model_config_enter("es_xf",      p_crires->es_xf,        i) ; i++ ;
    crires_model_config_enter("es_x_off",   p_crires->es_x_off,     i) ; i++ ;
    crires_model_config_enter("es_y",       p_crires->es_y,         i) ; i++ ;
    crires_model_config_enter("mues",       p_crires->mues/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("nues",       p_crires->nues/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("taues",      p_crires->taues/DEG2RAD,i) ; i++ ;
    crires_model_config_enter("es_s",       p_crires->es_s,         i) ; i++ ;
    crires_model_config_enter("es_w",       p_crires->es_w,         i) ; i++ ;
    crires_model_config_enter("fcp",        p_crires->fcp,          i) ; i++ ;
    crires_model_config_enter("mup1",       p_crires->mup1/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("axis_mup",   p_crires->axis_mup/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("penc_co1",   p_crires->penc_co1/DEG2RAD, i) ;i++;
    crires_model_config_enter("penc_co2",   p_crires->penc_co2/DEG2RAD, i) ;i++;
    crires_model_config_enter("penc_co3",   p_crires->penc_co3/DEG2RAD, i) ;i++;
    crires_model_config_enter("nup1",       p_crires->nup1/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("taup1",      p_crires->taup1/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("axis_nup",   p_crires->axis_nup/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("axis_taup",  p_crires->axis_taup/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("mup2",       p_crires->mup2/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("nup2",       p_crires->nup2/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("taup2",      p_crires->taup2/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("rind_delta", p_crires->rind_delta,   i) ; i++ ;
    crires_model_config_enter("muis",       p_crires->muis/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("nuis",       p_crires->nuis/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("tauis",      p_crires->tauis/DEG2RAD,i) ; i++ ;
    crires_model_config_enter("flipisx",    p_crires->flipisx,      i) ; i++ ;
    crires_model_config_enter("flipisy",    p_crires->flipisy,      i) ; i++ ;
    crires_model_config_enter("fis",        p_crires->fis,          i) ; i++ ;
    crires_model_config_enter("slitx",      p_crires->slitx,        i) ; i++ ;
    crires_model_config_enter("slity",      p_crires->slity,        i) ; i++ ;
    crires_model_config_enter("slitrot",    p_crires->slitrot/DEG2RAD, i) ; i++;
    crires_model_config_enter("slitw",      p_crires->slitw,        i) ; i++ ;
    crires_model_config_enter("slith",      p_crires->slith,        i) ; i++ ;
    crires_model_config_enter("slit_on",    p_crires->slit_on,      i) ; i++ ;
    crires_model_config_enter("mug",        p_crires->mug/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("axis_mug",   p_crires->axis_mug/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("genc_co1",   p_crires->genc_co1/DEG2RAD, i) ;i++;
    crires_model_config_enter("genc_co2",   p_crires->genc_co2/DEG2RAD, i) ;i++;
    crires_model_config_enter("genc_co3",   p_crires->genc_co3/DEG2RAD, i) ;i++;
    crires_model_config_enter("axis_nug",   p_crires->axis_nug/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("axis_taug",  p_crires->axis_taug/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("nug",        p_crires->nug/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("taug",       p_crires->taug/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("sg",         p_crires->sg,           i) ; i++ ;
    crires_model_config_enter("cam_dis",    p_crires->cam_dis,      i) ; i++ ;
    crires_model_config_enter("fk",         p_crires->fk,           i) ; i++ ;
    crires_model_config_enter("mud",        p_crires->mud/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("nud",        p_crires->nud/DEG2RAD,  i) ; i++ ;
    crires_model_config_enter("taud",       p_crires->taud/DEG2RAD, i) ; i++ ;
    crires_model_config_enter("pix",        p_crires->pix,          i) ; i++ ;
    crires_model_config_enter("chipx[0]",   p_crires->chipx[0],     i) ; i++ ;
    crires_model_config_enter("chipy[0]",   p_crires->chipy[0],     i) ; i++ ;
    crires_model_config_enter("chiprot[0]", p_crires->chiprot[0]/DEG2RAD,i);i++;
    crires_model_config_enter("chipx[1]",   p_crires->chipx[1],     i) ; i++ ;
    crires_model_config_enter("chipy[1]",   p_crires->chipy[1],     i) ; i++ ;
    crires_model_config_enter("chiprot[1]", p_crires->chiprot[1]/DEG2RAD,i);i++;
    crires_model_config_enter("chipx[2]",   p_crires->chipx[2],     i) ; i++ ;
    crires_model_config_enter("chipy[2]",   p_crires->chipy[2],     i) ; i++ ;
    crires_model_config_enter("chiprot[2]", p_crires->chiprot[2]/DEG2RAD,i);i++;
    crires_model_config_enter("chipx[3]",   p_crires->chipx[3],     i) ; i++ ;
    crires_model_config_enter("chipy[3]",   p_crires->chipy[3],     i) ; i++ ;
    crires_model_config_enter("chiprot[3]", p_crires->chiprot[3]/DEG2RAD,i);i++;
    crires_model_config_enter("pc_x_xx[0]",   p_crires->pc_x_xx[0],     i) ; i++ ;
    crires_model_config_enter("pc_x_x1[0]",   p_crires->pc_x_x1[0],     i) ; i++ ;
    crires_model_config_enter("pc_x_yy[0]",   p_crires->pc_x_yy[0],     i) ; i++ ;
    crires_model_config_enter("pc_x_y1[0]",   p_crires->pc_x_y1[0],     i) ; i++ ;
    crires_model_config_enter("pc_x_xy[0]",   p_crires->pc_x_xy[0],     i) ; i++ ;
    crires_model_config_enter("pc_y_xx[0]",   p_crires->pc_y_xx[0],     i) ; i++ ;
    crires_model_config_enter("pc_y_x1[0]",   p_crires->pc_y_x1[0],     i) ; i++ ;
    crires_model_config_enter("pc_y_yy[0]",   p_crires->pc_y_yy[0],     i) ; i++ ;
    crires_model_config_enter("pc_y_y1[0]",   p_crires->pc_y_y1[0],     i) ; i++ ;
    crires_model_config_enter("pc_y_xy[0]",   p_crires->pc_y_xy[0],     i) ; i++ ;
    crires_model_config_enter("pc_x_xx[1]",   p_crires->pc_x_xx[1],     i) ; i++ ;
    crires_model_config_enter("pc_x_x1[1]",   p_crires->pc_x_x1[1],     i) ; i++ ;
    crires_model_config_enter("pc_x_yy[1]",   p_crires->pc_x_yy[1],     i) ; i++ ;
    crires_model_config_enter("pc_x_y1[1]",   p_crires->pc_x_y1[1],     i) ; i++ ;
    crires_model_config_enter("pc_x_xy[1]",   p_crires->pc_x_xy[1],     i) ; i++ ;
    crires_model_config_enter("pc_y_xx[1]",   p_crires->pc_y_xx[1],     i) ; i++ ;
    crires_model_config_enter("pc_y_x1[1]",   p_crires->pc_y_x1[1],     i) ; i++ ;
    crires_model_config_enter("pc_y_yy[1]",   p_crires->pc_y_yy[1],     i) ; i++ ;
    crires_model_config_enter("pc_y_y1[1]",   p_crires->pc_y_y1[1],     i) ; i++ ;
    crires_model_config_enter("pc_y_xy[1]",   p_crires->pc_y_xy[1],     i) ; i++ ;
    crires_model_config_enter("pc_x_xx[2]",   p_crires->pc_x_xx[2],     i) ; i++ ;
    crires_model_config_enter("pc_x_x1[2]",   p_crires->pc_x_x1[2],     i) ; i++ ;
    crires_model_config_enter("pc_x_yy[2]",   p_crires->pc_x_yy[2],     i) ; i++ ;
    crires_model_config_enter("pc_x_y1[2]",   p_crires->pc_x_y1[2],     i) ; i++ ;
    crires_model_config_enter("pc_x_xy[2]",   p_crires->pc_x_xy[2],     i) ; i++ ;
    crires_model_config_enter("pc_y_xx[2]",   p_crires->pc_y_xx[2],     i) ; i++ ;
    crires_model_config_enter("pc_y_x1[2]",   p_crires->pc_y_x1[2],     i) ; i++ ;
    crires_model_config_enter("pc_y_yy[2]",   p_crires->pc_y_yy[2],     i) ; i++ ;
    crires_model_config_enter("pc_y_y1[2]",   p_crires->pc_y_y1[2],     i) ; i++ ;
    crires_model_config_enter("pc_y_xy[2]",   p_crires->pc_y_xy[2],     i) ; i++ ;
    crires_model_config_enter("pc_x_xx[3]",   p_crires->pc_x_xx[3],     i) ; i++ ;
    crires_model_config_enter("pc_x_x1[3]",   p_crires->pc_x_x1[3],     i) ; i++ ;
    crires_model_config_enter("pc_x_yy[3]",   p_crires->pc_x_yy[3],     i) ; i++ ;
    crires_model_config_enter("pc_x_y1[3]",   p_crires->pc_x_y1[3],     i) ; i++ ;
    crires_model_config_enter("pc_x_xy[3]",   p_crires->pc_x_xy[3],     i) ; i++ ;
    crires_model_config_enter("pc_y_xx[3]",   p_crires->pc_y_xx[3],     i) ; i++ ;
    crires_model_config_enter("pc_y_x1[3]",   p_crires->pc_y_x1[3],     i) ; i++ ;
    crires_model_config_enter("pc_y_yy[3]",   p_crires->pc_y_yy[3],     i) ; i++ ;
    crires_model_config_enter("pc_y_y1[3]",   p_crires->pc_y_y1[3],     i) ; i++ ;
    crires_model_config_enter("pc_y_xy[3]",   p_crires->pc_y_xy[3],     i) ; i++ ;
    crires_model_config_enter("det_array_x",p_crires->det_array_x,  i) ; i++ ;
    crires_model_config_enter("det_array_y",p_crires->det_array_y,  i) ; i++ ;
    crires_model_config_enter("offx",       p_crires->offx,         i) ; i++ ;
    crires_model_config_enter("offy",       p_crires->offy,         i) ; i++ ;
    crires_model_config_enter("flipx",      p_crires->flipx,        i) ; i++ ;
    crires_model_config_enter("flipy",      p_crires->flipy,        i) ; i++ ;

    if (p_crires->ord[59]!=-999) {

      for (j=1 ; j<60 ; j++) {
        sprintf(tempstr, "prism[%d]", j) ;
        crires_model_config_enter(tempstr,  p_crires->prism[j]/DEG2RAD,     i) ; i++ ;
        sprintf(tempstr, "grat[%d]", j) ;
        crires_model_config_enter(tempstr,  p_crires->grat[j]/DEG2RAD,i) ; i++ ;
        sprintf(tempstr, "ord[%d]", j) ;
        crires_model_config_enter(tempstr,  p_crires->ord[j],       i) ; i++ ;
      }
    }
    for (j=1 ; j<10 ; j++) {
      sprintf(tempstr, "slit[%d]", j) ;
      crires_model_config_enter(tempstr,  p_crires->slit[j],      i) ; i++ ;
    }
    return tab ;
}

void crires_model_io_output_cfg_txt(struct crires *p_crires)
{
    char            tempstr[10];
    int             i, j ;
    FILE * tempcfg;

    /* Initialise */
    
    tempcfg=fopen("tempcfg","w");

  i = 0 ;
  fprintf(tempcfg,"%lf %lf %lf %d temper\n",     p_crires->temper,p_crires->temper,p_crires->temper,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_x\n",      p_crires->es_x,p_crires->es_x,p_crires->es_x,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_xf\n",      p_crires->es_xf,p_crires->es_xf,p_crires->es_xf,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_x_off\n",   p_crires->es_x_off,p_crires->es_x_off,p_crires->es_x_off,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_y\n",       p_crires->es_y,p_crires->es_y,p_crires->es_y,0);
  fprintf(tempcfg,"%lf %lf %lf %d mues\n",       p_crires->mues/DEG2RAD,p_crires->mues/DEG2RAD,p_crires->mues/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nues\n",       p_crires->nues/DEG2RAD,p_crires->nues/DEG2RAD,p_crires->nues/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d taues\n",      p_crires->taues/DEG2RAD,p_crires->taues/DEG2RAD,p_crires->taues/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_s\n",       p_crires->es_s,p_crires->es_s,p_crires->es_s,0);
  fprintf(tempcfg,"%lf %lf %lf %d es_w\n",       p_crires->es_w,p_crires->es_w,p_crires->es_w,0);
  fprintf(tempcfg,"%lf %lf %lf %d fcp\n",        p_crires->fcp,p_crires->fcp,p_crires->fcp,0);
  fprintf(tempcfg,"%lf %lf %lf %d mup1\n",       p_crires->mup1/DEG2RAD,p_crires->mup1/DEG2RAD,p_crires->mup1/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_mup\n",       p_crires->axis_mup/DEG2RAD,p_crires->axis_mup/DEG2RAD,p_crires->axis_mup/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d penc_co1\n",   p_crires->penc_co1/DEG2RAD,p_crires->penc_co1/DEG2RAD,p_crires->penc_co1/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d penc_co2\n",   p_crires->penc_co2/DEG2RAD,p_crires->penc_co2/DEG2RAD,p_crires->penc_co2/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d penc_co3\n",   p_crires->penc_co3/DEG2RAD,p_crires->penc_co3/DEG2RAD,p_crires->penc_co3/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nup1\n",       p_crires->nup1/DEG2RAD,p_crires->nup1/DEG2RAD,p_crires->nup1/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d taup1\n",      p_crires->taup1/DEG2RAD,p_crires->taup1/DEG2RAD,p_crires->taup1/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_nup\n",       p_crires->axis_nup/DEG2RAD,p_crires->axis_nup/DEG2RAD,p_crires->axis_nup/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_taup\n",      p_crires->axis_taup/DEG2RAD,p_crires->axis_taup/DEG2RAD,p_crires->axis_taup/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d mup2\n",       p_crires->mup2/DEG2RAD,p_crires->mup2/DEG2RAD,p_crires->mup2/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nup2\n",       p_crires->nup2/DEG2RAD,p_crires->nup2/DEG2RAD,p_crires->nup2/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d taup2\n",      p_crires->taup2/DEG2RAD,p_crires->taup2/DEG2RAD,p_crires->taup2/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d rind_delta\n", p_crires->rind_delta,p_crires->rind_delta,p_crires->rind_delta,0);
  fprintf(tempcfg,"%lf %lf %lf %d muis\n",       p_crires->muis/DEG2RAD,p_crires->muis/DEG2RAD,p_crires->muis/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nuis\n",       p_crires->nuis/DEG2RAD,p_crires->nuis/DEG2RAD,p_crires->nuis/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d tauis\n",      p_crires->tauis/DEG2RAD,p_crires->tauis/DEG2RAD,p_crires->tauis/DEG2RAD,0);
  fprintf(tempcfg,"%d %d %d %d flipisx\n",    p_crires->flipisx,p_crires->flipisx,p_crires->flipisx,0);
  fprintf(tempcfg,"%d %d %d %d flipisy\n",    p_crires->flipisy,p_crires->flipisy,p_crires->flipisy,0);
  fprintf(tempcfg,"%lf %lf %lf %d fis\n",        p_crires->fis,p_crires->fis,p_crires->fis,0);
  fprintf(tempcfg,"%lf %lf %lf %d slitx\n",      p_crires->slitx,p_crires->slitx,p_crires->slitx,0);
  fprintf(tempcfg,"%lf %lf %lf %d slity\n",      p_crires->slity,p_crires->slity,p_crires->slity,0);
  fprintf(tempcfg,"%lf %lf %lf %d slitrot\n",    p_crires->slitrot/DEG2RAD,p_crires->slitrot/DEG2RAD,p_crires->slitrot/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d slitw\n",      p_crires->slitw,p_crires->slitw,p_crires->slitw,0);
  fprintf(tempcfg,"%lf %lf %lf %d slith\n",      p_crires->slith,p_crires->slith,p_crires->slith,0);
  fprintf(tempcfg,"%d %d %d %d slit_on\n",    p_crires->slit_on,p_crires->slit_on,p_crires->slit_on,0);
  fprintf(tempcfg,"%lf %lf %lf %d mug\n",        p_crires->mug/DEG2RAD,p_crires->mug/DEG2RAD,p_crires->mug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_mug\n",        p_crires->axis_mug/DEG2RAD,p_crires->axis_mug/DEG2RAD,p_crires->axis_mug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d genc_co1\n",   p_crires->genc_co1/DEG2RAD,p_crires->genc_co1/DEG2RAD,p_crires->genc_co1/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d genc_co2\n",   p_crires->genc_co2/DEG2RAD,p_crires->genc_co2/DEG2RAD,p_crires->genc_co2/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d genc_co3\n",   p_crires->genc_co3/DEG2RAD,p_crires->genc_co3/DEG2RAD,p_crires->genc_co3/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nug\n",        p_crires->nug/DEG2RAD,p_crires->nug/DEG2RAD,p_crires->nug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d taug\n",       p_crires->taug/DEG2RAD,p_crires->taug/DEG2RAD,p_crires->taug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_nug\n",        p_crires->axis_nug/DEG2RAD,p_crires->axis_nug/DEG2RAD,p_crires->axis_nug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d axis_taug\n",       p_crires->axis_taug/DEG2RAD,p_crires->axis_taug/DEG2RAD,p_crires->axis_taug/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d sg\n",         p_crires->sg,p_crires->sg,p_crires->sg,0);
  fprintf(tempcfg,"%lf %lf %lf %d cam_dis\n",    p_crires->cam_dis,p_crires->cam_dis,p_crires->cam_dis,0);
  fprintf(tempcfg,"%lf %lf %lf %d fk\n",         p_crires->fk,p_crires->fk,p_crires->fk,0);
  fprintf(tempcfg,"%lf %lf %lf %d mud\n",        p_crires->mud/DEG2RAD,p_crires->mud/DEG2RAD,p_crires->mud/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d nud\n",        p_crires->nud/DEG2RAD,p_crires->nud/DEG2RAD,p_crires->nud/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d taud\n",       p_crires->taud/DEG2RAD,p_crires->taud/DEG2RAD,p_crires->taud/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d pix\n",        p_crires->pix,p_crires->pix,p_crires->pix,0);
  fprintf(tempcfg,"%lf %lf %lf %d chipx[0]\n",   p_crires->chipx[0],p_crires->chipx[0],p_crires->chipx[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d chipy[0]\n",   p_crires->chipy[0],p_crires->chipy[0],p_crires->chipy[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d chiprot[0]\n", p_crires->chiprot[0]/DEG2RAD,p_crires->chiprot[0]/DEG2RAD,p_crires->chiprot[0]/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d chipx[1]\n",   p_crires->chipx[1],p_crires->chipx[1],p_crires->chipx[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d chipy[1]\n",   p_crires->chipy[1],p_crires->chipy[1],p_crires->chipy[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d chiprot[1]\n", p_crires->chiprot[1]/DEG2RAD,p_crires->chiprot[1]/DEG2RAD,p_crires->chiprot[1]/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d chipx[2]\n",   p_crires->chipx[2],p_crires->chipx[2],p_crires->chipx[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d chipy[2]\n",   p_crires->chipy[2],p_crires->chipy[2],p_crires->chipy[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d chiprot[2]\n", p_crires->chiprot[2]/DEG2RAD,p_crires->chiprot[2]/DEG2RAD,p_crires->chiprot[2]/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d chipx[3]\n",   p_crires->chipx[3],p_crires->chipx[3],p_crires->chipx[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d chipy[3]\n",   p_crires->chipy[3],p_crires->chipy[3],p_crires->chipy[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d chiprot[3]\n", p_crires->chiprot[3]/DEG2RAD,p_crires->chiprot[3]/DEG2RAD,p_crires->chiprot[3]/DEG2RAD,0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xx[0]\n",   p_crires->pc_x_xx[0],p_crires->pc_x_xx[0],p_crires->pc_x_xx[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_x1[0]\n",   p_crires->pc_x_x1[0],p_crires->pc_x_x1[0],p_crires->pc_x_x1[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_yy[0]\n",   p_crires->pc_x_yy[0],p_crires->pc_x_yy[0],p_crires->pc_x_yy[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_y1[0]\n",   p_crires->pc_x_y1[0],p_crires->pc_x_y1[0],p_crires->pc_x_y1[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xy[0]\n",   p_crires->pc_x_xy[0],p_crires->pc_x_xy[0],p_crires->pc_x_xy[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xx[0]\n",   p_crires->pc_y_xx[0],p_crires->pc_y_xx[0],p_crires->pc_y_xx[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_x1[0]\n",   p_crires->pc_y_x1[0],p_crires->pc_y_x1[0],p_crires->pc_y_x1[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_yy[0]\n",   p_crires->pc_y_yy[0],p_crires->pc_y_yy[0],p_crires->pc_y_yy[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_y1[0]\n",   p_crires->pc_y_y1[0],p_crires->pc_y_y1[0],p_crires->pc_y_y1[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xy[0]\n",   p_crires->pc_y_xy[0],p_crires->pc_y_xy[0],p_crires->pc_y_xy[0],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xx[1]\n",   p_crires->pc_x_xx[1],p_crires->pc_x_xx[1],p_crires->pc_x_xx[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_x1[1]\n",   p_crires->pc_x_x1[1],p_crires->pc_x_x1[1],p_crires->pc_x_x1[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_yy[1]\n",   p_crires->pc_x_yy[1],p_crires->pc_x_yy[1],p_crires->pc_x_yy[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_y1[1]\n",   p_crires->pc_x_y1[1],p_crires->pc_x_y1[1],p_crires->pc_x_y1[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xy[1]\n",   p_crires->pc_x_xy[1],p_crires->pc_x_xy[1],p_crires->pc_x_xy[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xx[1]\n",   p_crires->pc_y_xx[1],p_crires->pc_y_xx[1],p_crires->pc_y_xx[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_x1[1]\n",   p_crires->pc_y_x1[1],p_crires->pc_y_x1[1],p_crires->pc_y_x1[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_yy[1]\n",   p_crires->pc_y_yy[1],p_crires->pc_y_yy[1],p_crires->pc_y_yy[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_y1[1]\n",   p_crires->pc_y_y1[1],p_crires->pc_y_y1[1],p_crires->pc_y_y1[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xy[1]\n",   p_crires->pc_y_xy[1],p_crires->pc_y_xy[1],p_crires->pc_y_xy[1],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xx[2]\n",   p_crires->pc_x_xx[2],p_crires->pc_x_xx[2],p_crires->pc_x_xx[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_x1[2]\n",   p_crires->pc_x_x1[2],p_crires->pc_x_x1[2],p_crires->pc_x_x1[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_yy[2]\n",   p_crires->pc_x_yy[2],p_crires->pc_x_yy[2],p_crires->pc_x_yy[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_y1[2]\n",   p_crires->pc_x_y1[2],p_crires->pc_x_y1[2],p_crires->pc_x_y1[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xy[2]\n",   p_crires->pc_x_xy[2],p_crires->pc_x_xy[2],p_crires->pc_x_xy[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xx[2]\n",   p_crires->pc_y_xx[2],p_crires->pc_y_xx[2],p_crires->pc_y_xx[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_x1[2]\n",   p_crires->pc_y_x1[2],p_crires->pc_y_x1[2],p_crires->pc_y_x1[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_yy[2]\n",   p_crires->pc_y_yy[2],p_crires->pc_y_yy[2],p_crires->pc_y_yy[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_y1[2]\n",   p_crires->pc_y_y1[2],p_crires->pc_y_y1[2],p_crires->pc_y_y1[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xy[2]\n",   p_crires->pc_y_xy[2],p_crires->pc_y_xy[2],p_crires->pc_y_xy[2],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xx[3]\n",   p_crires->pc_x_xx[3],p_crires->pc_x_xx[3],p_crires->pc_x_xx[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_x1[3]\n",   p_crires->pc_x_x1[3],p_crires->pc_x_x1[3],p_crires->pc_x_x1[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_yy[3]\n",   p_crires->pc_x_yy[3],p_crires->pc_x_yy[3],p_crires->pc_x_yy[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_y1[3]\n",   p_crires->pc_x_y1[3],p_crires->pc_x_y1[3],p_crires->pc_x_y1[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_x_xy[3]\n",   p_crires->pc_x_xy[3],p_crires->pc_x_xy[3],p_crires->pc_x_xy[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xx[3]\n",   p_crires->pc_y_xx[3],p_crires->pc_y_xx[3],p_crires->pc_y_xx[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_x1[3]\n",   p_crires->pc_y_x1[3],p_crires->pc_y_x1[3],p_crires->pc_y_x1[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_yy[3]\n",   p_crires->pc_y_yy[3],p_crires->pc_y_yy[3],p_crires->pc_y_yy[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_y1[3]\n",   p_crires->pc_y_y1[3],p_crires->pc_y_y1[3],p_crires->pc_y_y1[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d pc_y_xy[3]\n",   p_crires->pc_y_xy[3],p_crires->pc_y_xy[3],p_crires->pc_y_xy[3],0);
  fprintf(tempcfg,"%lf %lf %lf %d det_array_x\n",p_crires->det_array_x,p_crires->det_array_x,p_crires->det_array_x,0);
  fprintf(tempcfg,"%lf %lf %lf %d det_array_y\n",p_crires->det_array_y,p_crires->det_array_y,p_crires->det_array_y,0);
  fprintf(tempcfg,"%lf %lf %lf %d offx\n",       p_crires->offx,p_crires->offx,p_crires->offx,0);
  fprintf(tempcfg,"%lf %lf %lf %d offy\n",       p_crires->offy,p_crires->offy,p_crires->offy,0);
  fprintf(tempcfg,"%d %d %d %d flipx\n",      p_crires->flipx,p_crires->flipx,p_crires->flipx,0);
  fprintf(tempcfg,"%d %d %d %d flipy\n",      p_crires->flipy,p_crires->flipy,p_crires->flipy,0);
  
  for (j=1 ; j<60 ; j++) {
    sprintf(tempstr, "prism[%d]", j) ;
    fprintf(tempcfg,"%lf %lf %lf %d %s \n",p_crires->prism[j]/DEG2RAD,p_crires->prism[j]/DEG2RAD,p_crires->prism[j]/DEG2RAD,0,tempstr);
    sprintf(tempstr, "grat[%d]", j) ;
    fprintf(tempcfg,"%lf %lf %lf %d %s \n",p_crires->grat[j]/DEG2RAD,p_crires->grat[j]/DEG2RAD,p_crires->grat[j]/DEG2RAD,0,tempstr);
    sprintf(tempstr, "ord[%d]", j) ;
    fprintf(tempcfg,"%d %d %d %d %s \n",p_crires->ord[j],p_crires->ord[j],p_crires->ord[j],0,tempstr);
  }
  for (j=1 ; j<10 ; j++) {
    sprintf(tempstr, "slit[%d]", j) ;
    fprintf(tempcfg,"%lf %lf %lf %d %s \n",p_crires->slit[j],p_crires->slit[j],p_crires->slit[j],0,tempstr);
  }
  fclose(tempcfg);
  return;
}

/**@}*/

