/* $Id: crires_utils.h,v 1.22 2012-10-09 08:18:01 yjung Exp $
 *
 * This file is part of the CRIRES Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: yjung $
 * $Date: 2012-10-09 08:18:01 $
 * $Revision: 1.22 $
 * $Name: not supported by cvs2svn $
 */

#ifndef CRIRES_UTILS_H
#define CRIRES_UTILS_H

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

/*-----------------------------------------------------------------------------
                                Define
 -----------------------------------------------------------------------------*/

#define CRIRES_NB_DETECTORS     4

/* GAIN */
#define CRIRES_GAIN_CHIP1       7.737 * 0.9
#define CRIRES_GAIN_CHIP2       7.664 * 0.9
#define CRIRES_GAIN_CHIP3       7.689 * 0.9
#define CRIRES_GAIN_CHIP4       8.077 * 0.9

/* RON_E */
#define CRIRES_RONE_CHIP1       9.9
#define CRIRES_RONE_CHIP2       9.7
#define CRIRES_RONE_CHIP3       9.6
#define CRIRES_RONE_CHIP4       10.0

/* Detector illumination */
#define CRIRES_ILLUM_P1_LY1     75
#define CRIRES_ILLUM_P1_UY1     430
#define CRIRES_ILLUM_P1_LY2     75
#define CRIRES_ILLUM_P1_UY2     430
#define CRIRES_ILLUM_P1_LY3     65
#define CRIRES_ILLUM_P1_UY3     420
#define CRIRES_ILLUM_P1_LY4     55
#define CRIRES_ILLUM_P1_UY4     410
#define CRIRES_ILLUM_P2_LY1     11
#define CRIRES_ILLUM_P2_UY1     361
#define CRIRES_ILLUM_P2_LY2     12
#define CRIRES_ILLUM_P2_UY2     362
#define CRIRES_ILLUM_P2_LY3     1
#define CRIRES_ILLUM_P2_UY3     351
#define CRIRES_ILLUM_P2_LY4     1
#define CRIRES_ILLUM_P2_UY4     351
#define CRIRES_ILLUM_P3_LY1     1
#define CRIRES_ILLUM_P3_UY1     512
#define CRIRES_ILLUM_P3_LY2     1
#define CRIRES_ILLUM_P3_UY2     512
#define CRIRES_ILLUM_P3_LY3     1
#define CRIRES_ILLUM_P3_UY3     512
#define CRIRES_ILLUM_P3_LY4     1
#define CRIRES_ILLUM_P3_UY4     512
typedef enum {
    CRIRES_ILLUM_UNKNOWN,
    CRIRES_ILLUM_FULL_DETECTOR, /* Take the full detector */
    CRIRES_ILLUM_LOWER_HALF,    /* Take the lower half of the detector */
    CRIRES_ILLUM_UPPER_HALF,    /* Take the upper half of the detector */
    CRIRES_ILLUM_PERIOD1,       /* Start      -> 05-02-2009 */
    CRIRES_ILLUM_PERIOD2,       /* 06-02-2009 -> 28-05-2009 */
    CRIRES_ILLUM_PERIOD3        /* 29-05-2009 -> Now */
} crires_illum_period ;

/* KEYWORDS */
#define CRIRES_HEADER_EXT_FORWARD   "DET CHIP|DET WIN NX|DET WIN NY|DET WIN STARTX|DET WIN STARTY"

/*-----------------------------------------------------------------------------
   							        Prototypes
 -----------------------------------------------------------------------------*/

const char * crires_get_license(void) ;
cpl_imagelist * crires_util_ilist_extend(const cpl_imagelist *, int) ;
cpl_imagelist * crires_util_ilist_extract(const cpl_imagelist *, int, int, int, 
        int) ;
cpl_image * crires_util_remove_gap(const cpl_image *, int) ;
cpl_image * crires_util_ima_merge(const cpl_image *, const cpl_image *) ;
int crire_stripe_keys_mismatch(const char *, const char *) ;
crires_illum_period crires_get_detector_illum_period(const char *) ;
void crires_display_detector_illum(crires_illum_period) ;
int crires_get_detector_ly1(crires_illum_period) ;
int crires_get_detector_uy1(crires_illum_period) ;
int crires_get_detector_ly2(crires_illum_period) ;
int crires_get_detector_uy2(crires_illum_period) ;
int crires_get_detector_ly3(crires_illum_period) ;
int crires_get_detector_uy3(crires_illum_period) ;
int crires_get_detector_ly4(crires_illum_period) ;
int crires_get_detector_uy4(crires_illum_period) ;
double crires_ra_hms2deg(int, int, double) ;
double crires_dec_hms2deg(int, int, double) ;
char * crires_get_root_name(const char *) ;
char * crires_get_base_name(const char *) ;
int crires_detlin_correct(cpl_imagelist *, crires_illum_period, 
        const char *, int, int, int, int) ;
int crires_bpm_correct_image(cpl_image *, crires_illum_period, 
        const char *, int) ;
int crires_model_off(void) ;
int crires_stripe_keys_check_off(void) ;
cpl_vector * crires_parse_y_positions(const char *) ;
cpl_vector * crires_read_y_positions(const char *, int) ;
int crires_get_y_spec_position(const char *, int) ;

#endif
